@@ -14,8 +14,10 @@ def bind(path, version_range=None, opts=None, parser=None):
 
     with make_package("os", path) as pkg:
         pkg.version = version
-        pkg.requires = ["platform-%s" % system.platform,
-                         "arch-%s" % system.arch]
+        pkg.requires = [
+            "platform-%s" % system.platform,
+            "arch-%s" % system.arch
+        ]
 
     return pkg.installed_variants
 
